@@ -15,11 +15,12 @@
 #include <bsoncxx/document/element.hpp>
 
 #include <cstdlib>
+#include <cstring>
 
 #include <bsoncxx/exception/error_code.hpp>
 #include <bsoncxx/exception/exception.hpp>
+#include <bsoncxx/json.hpp>
 #include <bsoncxx/private/libbson.hh>
-#include <bsoncxx/private/suppress_deprecation_warnings.hh>
 #include <bsoncxx/types.hpp>
 #include <bsoncxx/types/bson_value/value.hpp>
 #include <bsoncxx/types/bson_value/view.hpp>
@@ -78,8 +79,6 @@ stdx::string_view element::key() const {
     return stdx::string_view{key};
 }
 
-// CXX-1817; deprecation warning suppressed for get_utf8()
-BSONCXX_SUPPRESS_DEPRECATION_WARNINGS_BEGIN
 #define BSONCXX_ENUM(name, val)                                     \
     types::b_##name element::get_##name() const {                   \
         types::bson_value::view v{_raw, _length, _offset, _keylen}; \
@@ -87,23 +86,14 @@ BSONCXX_SUPPRESS_DEPRECATION_WARNINGS_BEGIN
     }
 #include <bsoncxx/enums/type.hpp>
 #undef BSONCXX_ENUM
-BSONCXX_SUPPRESS_DEPRECATION_WARNINGS_END
-
-types::b_utf8 element::get_string() const {
-    types::bson_value::view v{_raw, _length, _offset, _keylen};
-    return v.get_string();
-}
 
 types::bson_value::view element::get_value() const {
     switch (static_cast<int>(type())) {
-        // CXX-1817; deprecation warning suppressed for get_utf8()
-        BSONCXX_SUPPRESS_DEPRECATION_WARNINGS_BEGIN
 #define BSONCXX_ENUM(type, val) \
     case val:                   \
         return types::bson_value::view{get_##type()};
 #include <bsoncxx/enums/type.hpp>
 #undef BSONCXX_ENUM
-        BSONCXX_SUPPRESS_DEPRECATION_WARNINGS_END
     }
 
     BSONCXX_UNREACHABLE;
