@@ -17,7 +17,6 @@
 #include <chrono>
 #include <cstdint>
 #include <limits>
-#include <tuple>
 #include <utility>
 
 #include <bsoncxx/builder/basic/document.hpp>
@@ -29,39 +28,34 @@
 #include <bsoncxx/exception/exception.hpp>
 #include <bsoncxx/private/helpers.hh>
 #include <bsoncxx/private/libbson.hh>
-#include <bsoncxx/private/suppress_deprecation_warnings.hh>
 #include <bsoncxx/stdx/make_unique.hpp>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/types.hpp>
 #include <mongocxx/bulk_write.hpp>
 #include <mongocxx/client.hpp>
-#include <mongocxx/exception/bulk_write_exception.hpp>
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/exception/operation_exception.hpp>
 #include <mongocxx/exception/private/mongoc_error.hh>
 #include <mongocxx/exception/query_exception.hpp>
 #include <mongocxx/exception/write_exception.hpp>
+#include <mongocxx/hint.hpp>
 #include <mongocxx/model/write.hpp>
 #include <mongocxx/private/bulk_write.hh>
-#include <mongocxx/private/client.hh>
 #include <mongocxx/private/client_session.hh>
 #include <mongocxx/private/collection.hh>
 #include <mongocxx/private/cursor.hh>
-#include <mongocxx/private/database.hh>
 #include <mongocxx/private/libbson.hh>
 #include <mongocxx/private/libmongoc.hh>
 #include <mongocxx/private/pipeline.hh>
 #include <mongocxx/private/read_concern.hh>
 #include <mongocxx/private/read_preference.hh>
 #include <mongocxx/private/write_concern.hh>
-#include <mongocxx/result/bulk_write.hpp>
 #include <mongocxx/result/delete.hpp>
 #include <mongocxx/result/insert_many.hpp>
 #include <mongocxx/result/insert_one.hpp>
 #include <mongocxx/result/replace_one.hpp>
 #include <mongocxx/result/update.hpp>
-#include <mongocxx/stdx.hpp>
 #include <mongocxx/write_concern.hpp>
 
 #include <mongocxx/config/private/prelude.hh>
@@ -96,6 +90,7 @@ mongocxx::stdx::optional<bsoncxx::document::value> find_and_modify(
     mongoc_find_and_modify_flags_t flags,
     bool bypass,
     mongocxx::stdx::optional<bsoncxx::array::view_or_value> array_filters,
+    const mongocxx::stdx::optional<mongocxx::hint>& hint,
     const T& options) {
     using unique_opts =
         std::unique_ptr<mongoc_find_and_modify_opts_t,
@@ -134,6 +129,10 @@ mongocxx::stdx::optional<bsoncxx::document::value> find_and_modify(
         extra.append(kvp("arrayFilters", *array_filters));
     }
 
+    if (hint) {
+        extra.append(kvp("hint", hint->to_value()));
+    }
+
     scoped_bson_t extra_bson{extra.view()};
     mongocxx::libmongoc::find_and_modify_opts_append(opts.get(), extra_bson.bson());
 
@@ -301,6 +300,10 @@ namespace {
 bsoncxx::builder::basic::document build_find_options_document(const options::find& options) {
     bsoncxx::builder::basic::document options_builder;
 
+    if (options.allow_disk_use()) {
+        options_builder.append(kvp("allowDiskUse", *options.allow_disk_use()));
+    }
+
     if (options.allow_partial_results()) {
         options_builder.append(kvp("allowPartialResults", *options.allow_partial_results()));
     }
@@ -574,6 +577,9 @@ stdx::optional<result::replace_one> collection::_replace_one(const client_sessio
     if (options.collation()) {
         replace_op.collation(*options.collation());
     }
+    if (options.hint()) {
+        replace_op.hint(*options.hint());
+    }
     if (options.upsert()) {
         replace_op.upsert(*options.upsert());
     }
@@ -613,6 +619,9 @@ stdx::optional<result::update> collection::_update_many(const client_session* se
     if (options.collation()) {
         update_op.collation(*options.collation());
     }
+    if (options.hint()) {
+        update_op.hint(*options.hint());
+    }
     if (options.upsert()) {
         update_op.upsert(*options.upsert());
     }
@@ -690,6 +699,9 @@ stdx::optional<result::update> collection::_update_one(const client_session* ses
     if (options.collation()) {
         update_op.collation(*options.collation());
     }
+    if (options.hint()) {
+        update_op.hint(*options.hint());
+    }
     if (options.upsert()) {
         update_op.upsert(*options.upsert());
     }
@@ -762,6 +774,9 @@ stdx::optional<result::delete_result> collection::_delete_many(
     if (options.collation()) {
         delete_op.collation(*options.collation());
     }
+    if (options.hint()) {
+        delete_op.hint(*options.hint());
+    }
     bulk_op.append(delete_op);
 
     auto result = bulk_op.execute();
@@ -796,6 +811,9 @@ stdx::optional<result::delete_result> collection::_delete_one(
     if (options.collation()) {
         delete_op.collation(*options.collation());
     }
+    if (options.hint()) {
+        delete_op.hint(*options.hint());
+    }
     bulk_op.append(delete_op);
 
     auto result = bulk_op.execute();
@@ -837,6 +855,7 @@ stdx::optional<bsoncxx::document::value> collection::_find_one_and_replace(
                            flags,
                            options.bypass_document_validation().value_or(false),
                            stdx::nullopt,
+                           options.hint(),
                            options);
 }
 
@@ -874,6 +893,7 @@ stdx::optional<bsoncxx::document::value> collection::_find_one_and_update(
                            flags,
                            options.bypass_document_validation().value_or(false),
                            options.array_filters(),
+                           options.hint(),
                            options);
 }
 
@@ -931,6 +951,7 @@ stdx::optional<bsoncxx::document::value> collection::_find_one_and_delete(
                            MONGOC_FIND_AND_MODIFY_REMOVE,
                            false,
                            stdx::nullopt,
+                           options.hint(),
                            options);
 }
 
@@ -1269,7 +1290,7 @@ class change_stream collection::_watch(const client_session* session,
 }
 
 class index_view collection::indexes() {
-    return index_view{_get_impl().collection_t};
+    return index_view{_get_impl().collection_t, _get_impl().client_impl->client_t};
 }
 
 class bulk_write collection::_init_insert_many(const options::insert& options,
