@@ -15,10 +15,6 @@
 #pragma once
 
 #include <algorithm>
-#include <cstdint>
-#include <memory>
-#include <string>
-
 #include <bsoncxx/builder/basic/array.hpp>
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
@@ -30,6 +26,7 @@
 #include <mongocxx/bulk_write.hpp>
 #include <mongocxx/change_stream.hpp>
 #include <mongocxx/client_session.hpp>
+#include <mongocxx/config/prelude.hpp>
 #include <mongocxx/cursor.hpp>
 #include <mongocxx/index_view.hpp>
 #include <mongocxx/model/insert_one.hpp>
@@ -59,8 +56,7 @@
 #include <mongocxx/result/replace_one.hpp>
 #include <mongocxx/result/update.hpp>
 #include <mongocxx/write_concern.hpp>
-
-#include <mongocxx/config/prelude.hpp>
+#include <string>
 
 namespace mongocxx {
 MONGOCXX_INLINE_NAMESPACE_BEGIN
