@@ -129,6 +129,9 @@ TEST_CASE("session", "[session]") {
         auto a_id = value(session_a->id());
         auto b_id = value(session_b->id());
 
+        c["db"].run_command(*session_a, make_document(kvp("ping", 1)));
+        c["db"].run_command(*session_b, make_document(kvp("ping", 1)));
+
         // End session A, then session B.
         session_a = nullptr;
         session_b = nullptr;
@@ -207,7 +210,7 @@ TEST_CASE("session", "[session]") {
 
         // Test gridfs::bucket.
         auto bucket2 = db2.gridfs_bucket();
-        auto one = bsoncxx::types::value{bsoncxx::types::b_int32{1}};
+        auto one = bsoncxx::types::bson_value::view{bsoncxx::types::b_int32{1}};
 
         REQUIRE_THROWS_INVALID_SESSION(bucket2.open_upload_stream(s, "file"));
         REQUIRE_THROWS_INVALID_SESSION(bucket2.open_download_stream(s, one));
@@ -324,8 +327,8 @@ TEST_CASE("lsid", "[session]") {
             use_session ? db["fs.files"].drop(s) : db["fs.files"].drop();
             use_session ? db["fs.chunks"].drop(s) : db["fs.chunks"].drop();
 
-            auto one = bsoncxx::types::value{bsoncxx::types::b_int32{1}};
-            auto two = bsoncxx::types::value{bsoncxx::types::b_int32{2}};
+            auto one = bsoncxx::types::bson_value::view{bsoncxx::types::b_int32{1}};
+            auto two = bsoncxx::types::bson_value::view{bsoncxx::types::b_int32{2}};
             auto data = (uint8_t*)"foo";
             size_t len = 4;
             // Ensure multiple chunks.
@@ -358,11 +361,8 @@ TEST_CASE("lsid", "[session]") {
             use_session ? bucket.download_to_stream(s, two, &stream)
                         : bucket.download_to_stream(two, &stream);
 
-            int total = 0;
             auto cursor = use_session ? bucket.find(s, {}) : bucket.find({});
-            for (auto&& result : cursor) {
-                ++total;
-            }
+            auto total = std::distance(cursor.begin(), cursor.end());
 
             REQUIRE(total == 4);
             use_session ? bucket.delete_file(s, one) : bucket.delete_file(one);
@@ -373,12 +373,9 @@ TEST_CASE("lsid", "[session]") {
 
     SECTION("client::list_databases") {
         auto f = [&s, &test](bool use_session) {
-            int total = 0;
             auto cursor =
                 use_session ? test.client.list_databases(s) : test.client.list_databases();
-            for (auto&& result : cursor) {
-                ++total;
-            }
+            auto total = std::distance(cursor.begin(), cursor.end());
 
             REQUIRE(total > 0);
         };
@@ -390,12 +387,9 @@ TEST_CASE("lsid", "[session]") {
         auto f = [&s, &collection](bool use_session) {
             options::aggregate opts;
             opts.batch_size(2);
-            int total = 0;
             auto cursor =
                 use_session ? collection.aggregate(s, {}, opts) : collection.aggregate({}, opts);
-            for (auto&& doc : cursor) {
-                ++total;
-            }
+            auto total = std::distance(cursor.begin(), cursor.end());
 
             REQUIRE(total == 10);
         };
@@ -486,13 +480,9 @@ TEST_CASE("lsid", "[session]") {
         auto f = [&s, &collection](bool use_session) {
             options::find opts;
             opts.batch_size(2);
-            int total = 0;
             auto cursor = use_session ? collection.find(s, {}, opts) : collection.find({}, opts);
 
-            for (auto&& doc : cursor) {
-                ++total;
-            }
-
+            auto total = std::distance(cursor.begin(), cursor.end());
             REQUIRE(total == 10);
         };
 
@@ -541,7 +531,7 @@ TEST_CASE("lsid", "[session]") {
         std::vector<bsoncxx::document::view> docs{doc.view()};
 
         auto insert_vector = [&s, &collection, &docs](bool use_session) {
-            return use_session ? collection.insert_many(s, docs) : collection.insert_many(docs);
+            use_session ? collection.insert_many(s, docs) : collection.insert_many(docs);
         };
 
         test.test_method_with_session(insert_vector, s);
@@ -624,8 +614,8 @@ TEST_CASE("lsid", "[session]") {
             options::change_stream opts;
             opts.max_await_time(std::chrono::milliseconds(1));
             auto stream = use_session ? collection.watch(s, opts) : collection.watch(opts);
-            for (auto&& event : stream) {
-            }
+            for (auto it = stream.begin(); it != stream.end(); it++)
+                ;
         };
 
         test.test_method_with_session(f, s);
@@ -658,8 +648,8 @@ TEST_CASE("lsid", "[session]") {
     SECTION("database::list_collections") {
         auto f = [&s, &db](bool use_session) {
             auto cursor = use_session ? db.list_collections(s) : db.list_collections();
-            for (auto&& result : cursor) {
-            }
+            for (auto it = cursor.begin(); it != cursor.end(); it++)
+                ;
         };
 
         test.test_method_with_session(f, s);
@@ -668,8 +658,8 @@ TEST_CASE("lsid", "[session]") {
     SECTION("database::list_collection_names") {
         auto f = [&s, &db](bool use_session) {
             auto vector = use_session ? db.list_collection_names(s) : db.list_collection_names();
-            for (auto const& value : vector) {
-            }
+            for (auto it = vector.begin(); it != vector.end(); it++)
+                ;
         };
 
         test.test_method_with_session(f, s);
@@ -687,8 +677,8 @@ TEST_CASE("lsid", "[session]") {
     SECTION("index_view::list") {
         auto f = [&s, &indexes](bool use_session) {
             auto cursor = use_session ? indexes.list(s) : indexes.list();
-            for (auto&& i : cursor) {
-            }
+            for (auto it = cursor.begin(); it != cursor.end(); it++)
+                ;
         };
 
         test.test_method_with_session(f, s);
