@@ -242,8 +242,7 @@ class MONGOCXX_API write_concern {
     friend client;
     friend collection;
     friend database;
-    /// \relates mongocxx::options::transaction
-    friend mongocxx::options::transaction;
+    friend options::transaction;
     friend uri;
 
     ///
